@@ -1,6 +1,6 @@
 """
 EpyBake
-An Epytomil module
+An Epytoml module
 Created by: Zhean 'Z1aaan' Ganituen
 
 EpyBake is one of the most important modules of Epytoml.
@@ -10,41 +10,20 @@ Used for exporting the Epytoml created files to the supported markup languages o
 import os.path as path
 import os
 import pdfkit
-from Epytoml.Notaker import Notaker
-
-
-def bakePath(directory):
-    """Automatically format the directory to make it python-readable.
-
-    Args:
-        directory (str): The specific directory where you want EpyBake to export the files.
-
-    Returns:
-        The formatted, python-readable directory path.
-    """
-    # this function fixes the given directory path of the user
-    finalDirectory = ""
-    # duplicate \ of the directory
-    for char in directory:
-        if char == "\\":
-            finalDirectory += char + char
-        else:
-            finalDirectory += char
-
-    # join the directory with the filename
-    return directory
+import tkinter as tk
+from tkPDFViewer import tkPDFViewer
+from Epytoml import Notaker as ntk
 
 
 def ntkBake(fileName, exportTo=None, directory=None):
-    """Exports the file to html and pdf fileformat.
+    """Exports the file to html and pdf file format.
 
     Args:
         fileName (str): The file name of the exported file.
         exportTo (int, optional): Exports the file in html only, or html and pdf. Defaults to Both.
         directory (str, optional): Specific file directory you want the exported file to be located. Defaults to None.
     """
-
-    content = Notaker.ntk_ContWhole
+    content = ntk.ntk_ContWhole
     fileNameType = fileName + ".html"
 
     if directory is None or directory == 0:
@@ -91,3 +70,67 @@ def ntkBake(fileName, exportTo=None, directory=None):
                 with open(completeFileName, "w") as f:
                     f.write(content)
                 pdfkit.from_file(completeFileName, completeFileNamePDF)
+
+
+def preBake(filetype):
+    """Display the current output of the Epytoml file.
+
+    Args:
+        filetype (str): Specify what Epytoml file type is used.
+    """
+
+    def makeGUI():
+        # title of the preBake window
+        global root
+        root = tk.Tk()
+
+        root.title("Epytoml - EpyBake - preBake")
+
+        # contents of the GUI
+        # render pdf file in the tkinter GUI
+        pdfFile = tkPDFViewer.ShowPdf().pdf_view(
+            root, pdf_location=bakeFile, bar=False, width=75, height=50
+        )
+        pdfFile.grid(row=6, column=0, columnspan=10, rowspan=10)
+
+        root.mainloop()
+
+    def makeFile():
+        # export the file into html, then pdf, then delete the html file
+        # create both html and pdf files
+
+        # write an html file with the content of the notaker file
+
+        filename_html = bakeFile + ".html"
+        filename_pdf = bakeFile + ".pdf"
+
+        with open(filename_html, "w") as f:
+            f.write(file)
+
+        # convert the created html file into a pdf file
+        pdfkit.from_file(filename_html, filename_pdf)
+
+        # delete the created html file
+        os.remove(filename_html)
+
+    # store the filename of the notaker file created or the pdf file to be read
+    global filename
+    bakeFile = ""
+
+    filetype = filetype.upper()
+    
+    if filetype == "NOTAKER" or "NTK":
+        file = ntk.ntk_ContWhole
+        bakeFile = "preBake_Notaker"
+    
+
+    # run the makeFile function
+    makeFile()
+
+    bakeFile = bakeFile + ".pdf"
+
+    # run the makeGUI function
+    makeGUI()
+
+    # then once the GUI is closed, delete the created pdf file.
+    os.remove(bakeFile)
